Struct Psf2Header
Source struct Psf2Header {
pub header_size: u32,
pub glyph_count: u32,
pub bytes_per_glyph: u32,
pub width: u32,
pub height: u32,
}
Extract header fields from a raw PSF2 byte slice.
Panics
Panics if the magic number at offset 0 does not match [MAGIC_NUMBER].
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more
Returns the argument unchanged.
Calls U::from(self).
That is, this conversion is whatever the implementation of
[From]<T> for U chooses to do.
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.